@@ -440,7 +440,7 @@ EGA_errors <- function(data, n, plot.EGA, verbose, ...)
 
 #' @exportS3Method
 # S3 Print Method ----
-# Updated 02.08.2023
+# Updated 09.10.2024
 print.EGA <- function(x, ...)
 {
 
@@ -456,58 +456,63 @@ print.EGA <- function(x, ...)
   # Print community detection
   print(x$wc)
 
-  # Add break space
-  cat("\n----\n\n")
+  # Check for unidimensional attributes
+  if("unidimensional" %in% names(attributes(x))){
 
-  # Get unidimensional attributes
-  unidimensional_attributes <- attr(x, "unidimensional")
+    # Add break space
+    cat("\n----\n\n")
 
-  # Obtain unidimensional method
-  unidimensional_method <- switch(
-    unidimensional_attributes$uni.method,
-    "expand" = "Expand",
-    "le" = "Leading Eigenvector",
-    "louvain" = "Louvain"
-  )
+    # Get unidimensional attributes
+    unidimensional_attributes <- attr(x, "unidimensional")
 
-  # Set up unidimensional print
-  if(
-    unidimensional_method == "Louvain" &
-    "consensus.iter" %in% names(unidimensional_attributes$consensus)
-  ){
-
-    # Set up consensus attributes
-    consensus_attributes <- unidimensional_attributes$consensus
-
-    # Obtain consensus name
-    consensus_name <- switch(
-      consensus_attributes$consensus.method,
-      "highest_modularity" = "Highest Modularity",
-      "iterative" = "Iterative",
-      "most_common" = "Most Common",
-      "lowest_tefi" = "Lowest TEFI"
+    # Obtain unidimensional method
+    unidimensional_method <- switch(
+      unidimensional_attributes$uni.method,
+      "expand" = "Expand",
+      "le" = "Leading Eigenvector",
+      "louvain" = "Louvain"
     )
 
-    # Update unidimensional method text
-    unidimensional_method <- paste0(
-      unidimensional_method, " (", consensus_name,
-      " for ", consensus_attributes$consensus.iter,
-      " iterations)"
+    # Set up unidimensional print
+    if(
+      unidimensional_method == "Louvain" &
+      "consensus.iter" %in% names(unidimensional_attributes$consensus)
+    ){
+
+      # Set up consensus attributes
+      consensus_attributes <- unidimensional_attributes$consensus
+
+      # Obtain consensus name
+      consensus_name <- switch(
+        consensus_attributes$consensus.method,
+        "highest_modularity" = "Highest Modularity",
+        "iterative" = "Iterative",
+        "most_common" = "Most Common",
+        "lowest_tefi" = "Lowest TEFI"
+      )
+
+      # Update unidimensional method text
+      unidimensional_method <- paste0(
+        unidimensional_method, " (", consensus_name,
+        " for ", consensus_attributes$consensus.iter,
+        " iterations)"
+      )
+
+    }
+
+    # Print unidimensional
+    cat(
+      paste0(
+        "Unidimensional Method: ", unidimensional_method, "\n",
+        "Unidimensional: ", swiftelse(
+          unidimensional_attributes$unidimensional,
+          "Yes", "No"
+        )
+      )
     )
 
   }
 
-  # Print unidimensional
-  cat(
-    paste0(
-      "Unidimensional Method: ", unidimensional_method, "\n",
-      "Unidimensional: ", swiftelse(
-        unidimensional_attributes$unidimensional,
-        "Yes", "No"
-      )
-    )
-  )
-
   # Check for "TEFI" in output
   if("TEFI" %in% names(x)){
 
@@ -545,7 +550,7 @@ plot.EGA <- function(x, ...)
 }
 
 #' @noRd
-# Cleaning adjusts model arguments
+# Cleaning adjusts model arguments ----
 # Updated 23.06.2023
 adjust_model_arguments <- function(model_ARGS)
 {
