@@ -230,6 +230,8 @@
 #'
 #' \item{bootGraphs}{A list containing the networks of each replica sample}
 #'
+#' \item{bootCorrs}{A list containing the zero-order correlations of each replica sample}
+#'
 #' \item{boot.wc}{A matrix of membership assignments for each replica network
 #' with variables down the columns and replicas across the rows}
 #'
@@ -329,7 +331,7 @@
 #' @export
 #'
 # Bootstrap EGA ----
-# Updated 21.09.2024
+# Updated 30.01.2025
 bootEGA <- function(
     data, n = NULL,
     corr = c("auto", "cor_auto", "cosine", "pearson", "spearman"),
@@ -553,7 +555,7 @@ bootEGA <- function(
     args = obtain_arguments(  # ensures only proper arguments are passed
       dimensionStability,
       FUN.args = c(
-        list(bootega.obj = results, IS.plot = plot.itemStability),
+        list(bootega.obj = results, IS.plot = FALSE),
         ellipse
       )
     )
@@ -570,7 +572,7 @@ bootEGA <- function(
 
     # Order for rest of results
     results_order <- c(
-      "summary.table", "frequency", "bootGraphs",
+      "summary.table", "frequency", "bootGraphs", "bootCorrs",
       "boot.wc", "boot.ndim", "TEFI", "iter"
     )
 
@@ -585,7 +587,7 @@ bootEGA <- function(
     # Non-hierarchical results
     results <- results[c(
         "summary.table", "frequency", "stability",
-        "bootGraphs", "boot.wc", "boot.ndim", "TEFI",
+        "bootGraphs", "bootCorrs", "boot.wc", "boot.ndim", "TEFI",
         "EGA", "EGA.type", "type", "iter"
     )]
 
@@ -619,6 +621,14 @@ bootEGA <- function(
 
   }
 
+  # Check for plot (use `plot.itemStability`)
+  if(plot.itemStability){
+
+    # Plot results
+    plot(results, ...)
+
+  }
+
   # Restore random state (if there is one)
   restore_state()
 
@@ -699,7 +709,7 @@ bootEGA_errors <- function(
 
 #' @exportS3Method
 # S3 Print Method ----
-# Updated 31.03.2024
+# Updated 26.11.2024
 print.bootEGA <- function(x, ...)
 {
 
@@ -874,7 +884,7 @@ print.bootEGA <- function(x, ...)
     cat("\n")
 
     # Do not print unidimensional for `EGA.fit`
-    if(ega_type != "ega.fit"){
+    if(ega_type != "EGA.fit"){
 
       # Get unidimensional attributes
       unidimensional_attributes <- attr(ega_object, "unidimensional")
@@ -967,7 +977,7 @@ summary.bootEGA <- function(object, ...)
 
 #' @exportS3Method
 # S3 Plot Method ----
-# Updated 09.02.2024
+# Updated 30.01.2025
 plot.bootEGA <- function(x, ...)
 {
 
@@ -1023,8 +1033,31 @@ plot.bootEGA <- function(x, ...)
 
   }
 
-  # Always plot itemStability
-  plot(x$stability$item.stability)
+  # Switch out EGA type
+  ega_type <- switch(
+    x$EGA.type,
+    "ega" = "EGA",
+    "ega.fit" = "EGA + TEFI",
+    "hierega" = "Hierarchical EGA",
+    "riega" = "Random-intercept EGA"
+  )
+
+  # Plot empirical EGA
+  ega_plot <- plot(x$EGA, ...) +
+    ggplot2::ggtitle(paste("Original Sample |", ega_type)) +
+    ggplot2::theme(
+      plot.title = ggplot2::element_text(face = "bold", hjust = 0.5),
+      legend.position = "bottom"
+    )
+
+  # Plot with item stability
+  arranged <- ggpubr::ggarrange(
+    ega_plot, plot(x$stability$item.stability, plot.type = "empirical"),
+    nrow = 1, ncol = 2
+  )
+
+  # Make sure it plots
+  silent_plot(arranged)
 
 }
 
@@ -1127,18 +1160,10 @@ revalue_memberships <- function(bootstrap_EGA_output)
 #' @noRd
 # Prepare `bootEGA` results ----
 # Self-contained to work on `EGA` bootstraps
-# Updated 31.07.2023
+# Updated 23.01.2025
 prepare_bootEGA_results <- function(boot_object, iter)
 {
 
-  # Get networks
-  boot_networks <- lapply(boot_object, function(x){x$network})
-
-  # Get memberships
-  boot_memberships <- t(
-    nvapply(boot_object, function(x){x$wc}, LENGTH = length(boot_object[[1]]$wc))
-  )
-
   # Get bootstrap dimensions
   boot_n.dim <- nvapply(boot_object, function(x){x$n.dim})
 
@@ -1175,8 +1200,9 @@ prepare_bootEGA_results <- function(boot_object, iter)
   return(
     list(
       iter = iter,
-      bootGraphs = boot_networks,
-      boot.wc = boot_memberships,
+      bootGraphs = lapply(boot_object, function(x){x$network}),
+      bootCorrs = lapply(boot_object, function(x){x$correlation}),
+      boot.wc = t(nvapply(boot_object, function(x){x$wc}, LENGTH = length(boot_object[[1]]$wc))),
       boot.ndim = boot_n.dim,
       summary.table = summary_table,
       frequency = frequencies[
