@@ -12,9 +12,9 @@
 #'
 #' @param loading.method Character (length = 1).
 #' Sets network loading calculation based on implementation
-#' described in \code{"BRM"} (Christensen & Golino, 2021) or
-#' an \code{"experimental"} implementation.
-#' Defaults to \code{"BRM"}
+#' described in \code{"original"} (Christensen & Golino, 2021) or
+#' the \code{"revised"} (Christensen et al., 2024) implementation.
+#' Defaults to \code{"revised"}
 #'
 #' @param rotation Character.
 #' A rotation to use to obtain a simpler structure.
@@ -130,7 +130,7 @@
 #' }
 #'
 #' @param lower.algorithm Character or
-#' \code{\link{igraph}} \code{cluster_*} function (length = 1).
+#' \code{} \code{cluster_*} function (length = 1).
 #' Defaults to the lower order \code{"louvain"} with most common
 #' consensus clustering (1000 iterations; see
 #' \code{\link[EGAnet]{community.consensus}} for more details)
@@ -141,8 +141,8 @@
 #' capture lower order communities
 #'
 #' @param higher.algorithm Character or
-#' \code{\link{igraph}} \code{cluster_*} function (length = 1).
-#' Defaults to \code{"walktrap"}.
+#' \code{} \code{cluster_*} function (length = 1).
+#' Defaults to \code{"louvain"}.
 #' Three options are listed below but all are available
 #' (see \code{\link[EGAnet]{community.detection}} for other options):
 #'
@@ -150,11 +150,11 @@
 #'
 #' \item \code{"leiden"} --- See \code{\link[igraph]{cluster_leiden}} for more details
 #'
-#' \item \code{"louvain"} --- By default, \code{"louvain"} will implement the Louvain algorithm using
-#' the consensus clustering method (see \code{\link[EGAnet]{community.consensus}}
-#' for more information). This function will implement
-#' \code{consensus.method = "most_common"} and \code{consensus.iter = 1000}
-#' unless specified otherwise
+#' \item \code{"louvain"} --- By default, \code{"louvain"} will implement the higher-order
+#' (\code{order = "higher"}) Louvain algorithm using the consensus clustering method
+#' (see \code{\link[EGAnet]{community.consensus}} for more information).
+#' This function will implement \code{consensus.method = "most_common"} and
+#' \code{consensus.iter = 1000} unless specified otherwise
 #'
 #' \item \code{"walktrap"} --- See \code{\link[igraph]{cluster_walktrap}} for more details
 #'
@@ -233,6 +233,10 @@
 #' Dimensionality assessment in bifactor structures with multiple general factors: A network psychometrics approach.
 #' \emph{Psychological Methods}.
 #'
+#' \strong{3+ level hierarchical EGA} \cr
+#' Samo, A., Christensen, A. P., Abad, F. J., Garrido, L. E., Garcia-Garzon, E., Golino, H. & McAbee, S. T. (2023). Building the structure of personality from the bottom-up using Hierarchical Exploratory Graph Analysis.
+#' \emph{PsyArXiv}.
+#'
 #' \strong{Conceptual implementation} \cr
 #' Golino, H., Thiyagarajan, J. A., Sadana, R., Teles, M., Christensen, A. P., & Boker, S. M. (2020).
 #' Investigating the broad domains of intrinsic capacity, functional ability and
@@ -240,6 +244,11 @@
 #' methodologies for measuring healthy aging.
 #' \emph{PsyArXiv}.
 #'
+#' \strong{Revised network loadings} \cr
+#' Christensen, A. P., Golino, H., Abad, F. J., & Garrido, L. E. (2024).
+#' Revised network loadings.
+#' \emph{PsyArXiv}.
+#'
 #' @author
 #' Marcos Jiménez <marcosjnezhquez@gmailcom>,
 #' Francisco J. Abad <fjose.abad@uam.es>,
@@ -267,16 +276,16 @@
 #' # Plot levels separately
 #' plot(opt.hier, plot.type = "separate")}
 #'
-#' @seealso \code{\link[EGAnet]{plot.EGAnet}} for plot usage in \code{\link{EGAnet}}
+#' @seealso \code{\link[EGAnet]{plot.EGAnet}} for plot usage in \code{}
 #'
 #' @export
 #'
 # Hierarchical EGA ----
-# Updated 24.10.2023
+# Updated 12.08.2024
 hierEGA <- function(
     data,
     # `net.scores` arguments
-    loading.method = c("BRM", "experimental"),
+    loading.method = c("original", "revised"),
     rotation = NULL, scores = c("factor", "network"),
     loading.structure = c("simple", "full"),
     impute = c("mean", "median", "none"),
@@ -303,7 +312,8 @@ hierEGA <- function(
 
   # Check for missing arguments (argument, default, function)
   ## `net.scores`
-  loading.method <- set_default(loading.method, "brm", net.loads)
+  # loading.method <- set_default(loading.method, "experimental", net.loads)
+  # Push default check to `net.laods`
   scores <- set_default(scores, "network", hierEGA)
   loading.structure <- set_default(loading.structure, "simple", hierEGA)
   impute <- set_default(impute, "none", net.scores)
@@ -332,7 +342,7 @@ hierEGA <- function(
   algorithm <- lower.algorithm
   lower.algorithm <- set_default(algorithm, "louvain", community.detection)
   algorithm <- higher.algorithm
-  higher.algorithm <- set_default(algorithm, "walktrap", community.detection)
+  higher.algorithm <- set_default(algorithm, "louvain", community.detection)
 
   # Get EGA
   lower_order_result <- do.call(
